@@ -692,7 +692,11 @@ export class NotebookHelper {
     }
     await this.page.keyboard.press('Control+A');
     await this.page.keyboard.press('Control+C');
-    await this.page.context().grantPermissions(['clipboard-read']);
+    try {
+      await this.page.context().grantPermissions(['clipboard-read']);
+    } catch {
+      // Firefox does not support clipboard-read but does not it it either
+    }
     const handle = await this.page.evaluateHandle(() =>
       navigator.clipboard.readText()
     );
@@ -1129,7 +1133,7 @@ export class NotebookHelper {
       let break_ = true;
       try {
         await Utils.waitForCondition(
-          async () => ((await gutter.textContent())?.length ?? 0) > 0,
+          async () => (await gutter.locator('.cm-breakpoint-icon').count()) > 0,
           1000
         );
       } catch (reason) {
@@ -1260,7 +1264,7 @@ export class NotebookHelper {
 
     await this._setCellMode(cell, 'Edit');
     await cell.getByRole('textbox').press('Control+A');
-    await cell.getByRole('textbox').type(source, { delay: 0 });
+    await cell.getByRole('textbox').pressSequentially(source);
     await this._setCellMode(cell, 'Command');
 
     if (cellType === 'code') {
@@ -1414,16 +1418,36 @@ export class NotebookHelper {
   }
 
   /**
-   * Create a new notebook
+   * Creates a new notebook.
    *
-   * @param name Name of the notebook
-   * @returns Name of the created notebook or null if it failed
+   * @param name - The name of the notebook. If provided, the notebook will be renamed to this name.
+   * @param options - Parameters for creating the notebook.
+   * @param options.kernel - The kernel to use for the notebook.
+   * @returns A Promise that resolves to the name of the created notebook, or `null` if the notebook creation failed.
    */
-  async createNew(name?: string): Promise<string | null> {
+  async createNew(
+    name?: string,
+    options?: { kernel?: string | null }
+  ): Promise<string | null> {
     await this.menu.clickMenuItem('File>New>Notebook');
 
     const page = this.page;
     await page.locator('.jp-Dialog').waitFor();
+
+    if (options && options.kernel !== undefined) {
+      if (options.kernel === null) {
+        await page
+          .getByRole('dialog')
+          .getByRole('combobox')
+          .selectOption('null');
+      } else {
+        await page
+          .getByRole('dialog')
+          .getByRole('combobox')
+          .selectOption(`{"name":"${options.kernel}"}`);
+      }
+    }
+
     await page.click('.jp-Dialog .jp-mod-accept');
 
     const activeTab = this.activity.getTabLocator();
