@@ -1,6 +1,8 @@
-// Copyright (c) Jupyter Development Team.
-// Copyright (c) Bloomberg Finance LP.
-// Distributed under the terms of the Modified BSD License.
+/*
+ * Copyright (c) Jupyter Development Team.
+ * Distributed under the terms of the Modified BSD License.
+ * Copyright (c) Bloomberg Finance LP.
+ */
 /**
  * @packageDocumentation
  * @module galata
@@ -11,9 +13,9 @@
  */
 export { expect } from '@playwright/test';
 
+export * from './extension';
+
 export * from './benchmarkReporter';
 export * from './galata';
-export * from './global';
-export * from './inpage/tokens';
 export * from './fixtures';
 export * from './jupyterlabpage';
