@@ -312,9 +312,9 @@ src[STAR] = "(<|>)?=?\\s*\\*"
 
 # version name recovery for convenient
 RECOVERYVERSIONNAME = R()
-src[RECOVERYVERSIONNAME] = "v?({n})(?:\\.({n}))?{pre}?".format(
-    n=src[NUMERICIDENTIFIER], pre=src[PRERELEASELOOSE]
-)
+_n = src[NUMERICIDENTIFIER]
+_pre = src[PRERELEASELOOSE]
+src[RECOVERYVERSIONNAME] = f"v?({_n})(?:\\.({_n}))?{_pre}?"
 
 #  Compile to actual regexp objects.
 #  All are flag-free, unless they were created above with a flag.
@@ -954,7 +954,7 @@ def replace_caret(comp, loose):
             else:
                 ret = ">=" + M + "." + m + "." + (p or "") + pr + " <" + str(int(M) + 1) + ".0.0"
         else:
-            if M == "0":  # PLR5501
+            if M == "0":
                 if m == "0":
                     ret = (
                         ">="
@@ -1186,7 +1186,7 @@ def outside(version, range_, hilo, loose):
     else:
         raise ValueError("Must provide a hilo val of '<' or '>'")
 
-    #  If it satisifes the range it is not outside
+    #  If it satisfies the range it is not outside
     if satisfies(version, range_, loose):
         return False
 
